import bunyan from 'bunyan';
import { PathBuffer, CheckedContract } from '@ethereum-sourcify/core';
export interface IValidationService {
    /**
     * Checks all metadata files found in the provided paths. Paths may include regular files, directoris and zip archives.
     *
     * @param paths The array of paths to be searched and checked.
     * @param ignoring Optional array where all unreadable paths can be stored.
     * @returns An array of CheckedContract objects.
     * @throws Error if no metadata files are found.
     */
    checkPaths(paths: string[], ignoring?: string[]): CheckedContract[];
    /**
     * Checks the provided files. Works with zips.
     * Attempts to find all the resources specified in every metadata file found.
     *
     * @param files The array or object of buffers to be checked.
     * @returns An array of CheckedContract objets.
     * @throws Error if no metadata files are found.
     */
    checkFiles(files: PathBuffer[], unused?: string[]): CheckedContract[];
}
export declare class ValidationService implements IValidationService {
    logger: bunyan;
    /**
     * @param logger a custom logger that logs all errors; undefined or no logger provided turns the logging off
     */
    constructor(logger?: bunyan);
    checkPaths(paths: string[], ignoring?: string[]): CheckedContract[];
    checkFiles(files: PathBuffer[], unused?: string[]): CheckedContract[];
    /**
     * Traverses the given files, unzipping any zip archive.
     *
     * @param files the array containing the files to be checked
     * @returns an array containing the provided files, with any zips being unzipped and returned
     */
    private findInputFiles;
    /**
     * Checks whether the provided file is in fact zipped.
     * @param file the buffered file to be checked
     * @returns true if the file is zipped; false otherwise
     */
    private isZip;
    /**
     * Unzips the provided file buffer to the provided array.
     *
     * @param zippedFile the buffer containin the zipped file to be unpacked
     * @param files the array to be filled with the content of the zip
     */
    private unzip;
    /**
     * Selects metadata files from an array of files that may include sources, etc
     * @param  {string[]} files
     * @return {string[]}         metadata
     */
    private splitFiles;
    /**
     * Validates metadata content keccak hashes for all files and
     * returns mapping of file contents by file name
     * @param  {any}       metadata
     * @param  {Map<string, any>}  byHash    Map from keccak to source
     * @return foundSources, missingSources, invalidSources
     */
    private rearrangeSources;
    /**
     * Generates a map of files indexed by the keccak hash of their content.
     *
     * @param  {string[]}  files Array containing sources.
     * @returns Map object that maps hash to PathContent.
     */
    private storeByHash;
    private generateVariations;
    private extractUnused;
    private extractMetadataFromString;
    /**
     * A method that checks if the provided object was generated as a metadata file of a Solidity contract.
     * Current implementation is rather simplistic and may require further engineering.
     *
     * @param metadata the JSON to be checked
     * @returns true if the provided object is a Solidity metadata file; false otherwise
     */
    private isMetadata;
    /**
     * Applies the provided worker function to the provided path recursively.
     *
     * @param path the path to be traversed
     * @param worker the function to be applied on each file that is not a directory
     * @param afterDir the function to be applied on the directory after traversing its children
     */
    private traversePathRecursively;
    /**
     * Asserts that the number of keys of the provided object is expectedSize.
     * If not, logs an appropriate message (if log function provided) and throws an Error.
     * @param object the object to check
     * @param expectedSize the size that the object should have
     */
    private assertObjectSize;
}
